#######################
Developer documentation
#######################

.. toctree::
   :maxdepth: 3

   Developers Guide <Developers-Guide>
   Style guide <Style-guide>
   Testing <Testing>
   How to write a parser or (parser) plugin <How-to-write-a-parser>
   How to write an analysis plugin <How-to-write-an-analysis-plugin>
   How to write an output module <How-to-write-an-output-module>
   Packaging with Docker <Packaging-with-docker>
   Packaging with PyInstaller <Packaging-with-pyinstaller>
